@@ -270,18 +270,13 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
                 func = lambda x, r=cregex : r.match(x) == None
                 self.name_filters_available.append( TypeFilter(f.name, f.active, func) )
         self.name_filters = []
-        tips = gtk.Tooltips()
         for i,f in misc.enumerate(self.name_filters_available):
             icon = gtk.Image()
             icon.set_from_stock(gtk.STOCK_FIND, gtk.ICON_SIZE_LARGE_TOOLBAR)
-            toggle = gtk.ToggleToolButton()
-            toggle.set_property("label",f.label)
-            toggle.set_icon_widget(icon)
-            toggle.connect("toggled", lambda b,i=i : self._update_name_filter(b,i) )
+            icon.show()
+            toggle = self.toolbar.append_element(gtk.TOOLBAR_CHILD_TOGGLEBUTTON, None, f.label,
+                _("Hide %s") % f.label, "", icon, self._update_name_filter, i )
             toggle.set_active(f.active)
-            self.toolbar.insert(toggle, -1)
-            toggle.show_all()
-            toggle.set_tooltip(tips, _("Hide %s") % f.label )
 
     def on_preference_changed(self, key, value):
         if key == "toolbar_style":
@@ -360,7 +355,6 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
         self.scheduler.add_task( self._search_recursively_iter( path ).next )
 
     def _search_recursively_iter(self, rootpath):
-        self.filter_hide_current.set_sensitive(False)
         yield _("[%s] Scanning") % self.label_text
         prefixlen = 1 + len( self.model.value_path( self.model.get_iter(rootpath), 0 ) )
         symlinks_followed = {} # only follow symlinks once
@@ -476,7 +470,6 @@ class DirDiff(melddoc.MeldDoc, gnomeglade.Component):
                     level += 1
                     self.treeview[0].expand_row( path[:level], 0)
         yield _("[%s] Done") % self.label_text
-        self.filter_hide_current.set_sensitive(True)
 
     def launch_comparison(self, iter, pane, force=1):
         """Launch comparison at 'iter'. 
