@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2003 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2004 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -37,9 +37,15 @@ import paths
 
 sourceview_available = 0
 
-try:
-    import sourceview as gsv
-    sourceview_available = 1
+for sourceview in "gtksourceview sourceview".split():
+    try:
+        gsv = __import__(sourceview)
+        sourceview_available = 1
+        break
+    except ImportError:
+        pass
+
+if sourceview_available:
     def set_highlighting_enabled(buf, fname, enabled):
         # gnome.vfs.get_mime_type seems to be broken. fake it.
         extmap = { "xml":"text/xml",
@@ -67,8 +73,6 @@ try:
         if gsl:
             buf.set_language(gsl)
         buf.set_highlight(enabled)
-except ImportError:
-    pass
 
 gdk = gtk.gdk
 
@@ -86,7 +90,10 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
 
     keylookup = {gtk.keysyms.Shift_L : MASK_SHIFT,
                  gtk.keysyms.Control_L : MASK_CTRL,
-                 gtk.keysyms.Alt_L : MASK_ALT}
+                 gtk.keysyms.Alt_L : MASK_ALT,
+                 gtk.keysyms.Shift_R : MASK_SHIFT,
+                 gtk.keysyms.Control_R : MASK_CTRL,
+                 gtk.keysyms.Alt_R : MASK_ALT }
 
     def __init__(self, prefs, num_panes):
         """Start up an filediff with num_panes empty contents.
@@ -106,6 +113,10 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                 v.show()
                 w.add(v)
                 v.set_show_line_numbers(self.prefs.show_line_numbers)
+                for s in "key_press_event key_release_event".split():
+                    v.connect(s, getattr(self,"on_%s"%s))
+                for s in "button_press_event move_cursor focus_in_event".split():
+                    v.connect(s, getattr(self,"on_textview_%s"%s))
         self.keymask = 0
         self.load_font()
         self.deleted_lines_pending = -1
@@ -347,6 +358,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
             buttons = []
             for i in range(self.num_panes):
                 b = gtk.CheckButton( self._get_filename(i) )
+                b.set_use_underline(False)
                 buttons.append(b)
                 dialog.box.pack_start(b, 1, 1)
                 if not modified[i]:
@@ -722,8 +734,14 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                         if k != '\n':
                             text = text.replace('\n', k)
                         break
-        if bufdata.encoding:
-            text = text.encode(bufdata.encoding)
+        if bufdata.encoding and self.prefs.save_encoding==0:
+            try:
+                text = text.encode(bufdata.encoding)
+            except UnicodeEncodeError, e:
+                if misc.run_dialog(
+                    _("'%s' contains characters not encodable with '%s'\nWould you like to save as UTF-8?") % (bufdata.filename, bufdata.encoding),
+                    self, gtk.MESSAGE_ERROR, gtk.BUTTONS_YES_NO) != gtk.RESPONSE_YES:
+                    return melddoc.RESULT_ERROR
         try:
             open(bufdata.filename, "w").write(text)
         except IOError, e:
@@ -1127,11 +1145,11 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                 rect_x = wtotal - pix_width
             else:
                 return  1
-            adj = self.scrolledwindow[which+side].get_vadjustment()
-            func = lambda c: self._line_to_pixel(which, c[1]) - adj.value
-
             src = which + side
             dst = which + 1 - side
+            adj = self.scrolledwindow[src].get_vadjustment()
+            func = lambda c: self._line_to_pixel(src, c[1]) - adj.value
+
             for c in self.linediffer.pair_changes(src, dst, self._get_texts()):
                 if c[0] == "insert":
                     continue
